--
-- 3.4.0 TO 3.5.0 --
--
-- RUN THE COMMANDS BELOW AT THE COMMAND LINE
--
-- > pg_dump -U [DBNAME] -h [DBHOST] -f /tmp/genre.sql -D -O -t Genre -a ethereal
-- > pg_dump -U [DBNAME] -h [DBHOST] -f /tmp/gallery_genre.sql -D -O -t GalleryGenre -a ethereal
-- > pgql-U [DBNAME] -h [DBHOST] ethereal
--   [Paste in text below]


DROP VIEW ethereal.Exhibition;
DROP TABLE ethereal.GalleryGenre;
DROP TABLE ethereal.Genre;

CREATE TABLE ethereal.Genre (
  GenreName            VARCHAR(25)  NOT NULL,
  GenreOrder           VARCHAR(7)   NOT NULL DEFAULT 'realm',
  GenreDescription     VARCHAR(250),
  CONSTRAINT pkGenre                PRIMARY KEY (GenreName, GenreOrder),
  CONSTRAINT enumGenreOrder         CHECK (GenreOrder IN ('realm','comic','image','journal','text'))
) WITHOUT OIDS;
ALTER TABLE ethereal.Genre                 OWNER TO ethereal;
\i /tmp/genre.sql


CREATE TABLE ethereal.GalleryGenre (
  GalleryID            INT          NOT NULL,
  GenreName            VARCHAR(25)  NOT NULL,
  GenreOrder           VARCHAR(7)   NOT NULL,
  CONSTRAINT fkGenre_Gallery        FOREIGN KEY (GalleryID)
    REFERENCES ethereal.Gallery (GalleryID)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkGenre_Genre          FOREIGN KEY (GenreName, GenreOrder)
    REFERENCES ethereal.Genre (GenreName, GenreOrder)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
ALTER TABLE ethereal.GalleryGenre           OWNER TO ethereal;
\i /tmp/gallery_genre.sql



-- Constraint modification
ALTER TABLE ethereal.Gallery DROP CONSTRAINT enumGalleryType;
ALTER TABLE ethereal.Gallery ADD  CONSTRAINT enumGalleryType CHECK (GalleryType IN ('comic','image','initial','journal','text'));

-- Privacy control
ALTER TABLE ethereal.Gallery ADD GalleryPrivacy VARCHAR(3);
UPDATE ethereal.Gallery SET GalleryPrivacy='no';
ALTER TABLE ethereal.Gallery ALTER COLUMN GalleryPrivacy SET NOT NULL;
ALTER TABLE ethereal.Gallery ALTER COLUMN GalleryPrivacy SET DEFAULT 'no';
ALTER TABLE ethereal.Gallery ADD CONSTRAINT enumGalleryPrivacy CHECK (GalleryPrivacy IN ('yes','no'));

-- Introduction override
ALTER TABLE ethereal.Gallery ADD GalleryIntro TEXT;
ALTER TABLE ethereal.Gallery ADD GalleryWrkHeader TEXT;

-- Recreate view
CREATE VIEW ethereal.Exhibition AS
   SELECT
     gal.GalleryID          AS GalleryID,
     gal.PuppeteerLogin     AS PuppeteerLogin,
     gal.GalleryPenName     AS GalleryPenName,
     gal.GalleryName        AS GalleryName,
     gal.GalleryRating      AS GalleryRating,
     gal.GalleryDescription AS GalleryDescription,
     gal.GalleryType        AS GalleryType,
     gre.GenreName          AS GalleryGenre,
     gal.GalleryCreated     AS GalleryCreated,
     gal.GalleryUpdated     AS GalleryUpdated,
     (COUNT(wrk.WorkID)-2)  AS WorkCount
   FROM ethereal.Gallery gal, ethereal.Work wrk, ethereal.GalleryGenre gre
   WHERE gal.GalleryID = wrk.GalleryID
     AND gal.GalleryID = gre.GalleryID
     AND gal.GalleryPrivacy = 'no'
   GROUP BY gal.GalleryID,
            gal.PuppeteerLogin,
            gal.GalleryPenName,
            gal.GalleryName,
            gal.GalleryRating,
            gal.GalleryDescription,
            gal.GalleryType,
            gal.GalleryCreated,
            gal.GalleryUpdated,
            gre.GenreName
   HAVING COUNT(wrk.WorkID) > 2::INT;

ALTER TABLE ethereal.Exhibition            OWNER TO ethereal;


-- Addition of a seqence
CREATE SEQUENCE ethereal.seqLink    MAXVALUE 2147483647;
ALTER TABLE ethereal.seqLink               OWNER TO ethereal;

-- Addition of quick link table
CREATE TABLE ethereal.Link (
  LinkID               INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqLink'),
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  GalleryID            INT,
  LinkName             VARCHAR(20)   NOT NULL,
  LinkAddress          VARCHAR(250)  NOT NULL,
  CONSTRAINT pkLink                  PRIMARY KEY (LinkID),
  CONSTRAINT fkComment_Gallery       FOREIGN KEY (GalleryID)
    REFERENCES ethereal.Gallery (GalleryID)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkLinkPuppeteer         FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE

) WITHOUT OIDS;

-- STANDARD INDEX
CREATE INDEX idxLink_PuppeteerLogin ON ethereal.Link
(
  PuppeteerLogin
);

CREATE INDEX idxLink_GalleryId ON ethereal.Link
(
  GalleryID
);
ALTER TABLE ethereal.Link                  OWNER TO ethereal;

-- Addition of a tag zone
ALTER TABLE ethereal.Tag DROP CONSTRAINT enumTagType;
ALTER TABLE ethereal.Tag ADD  CONSTRAINT enumTagType CHECK (TagType IN ('admin','board','configuration','contrib','gallery','home','login','mail','poll','portal','realm','system','template','vcodes'));


-- Correction of database schema
ALTER TABLE ethereal.GalleryNotify ADD CONSTRAINT pkGalleryNotify         PRIMARY KEY (GalleryID, PuppeteerLogin);
ALTER TABLE ethereal.GalleryGenre  ADD CONSTRAINT pkGalleryGenre          PRIMARY KEY (GalleryID, GenreName, GenreOrder);
